Metadata models for images, audio info, genres, labels, and other metadata
This module contains various models for handling metadata such as images, audio information, genres, labels, tags, areas, awards, and other related metadata used in the Qobuz API.
Structs
- Area
- Area model containing information about a geographical area
- Audio
Info - Audio information model containing replay gain data
- Award
- Award model containing information about an award
- Focus
- Focus model containing information about a focused item
- Genre
- Genre model containing information about a musical genre
- Genre
Tag - Genre tag model containing information about a genre tag
- Goody
- Goody model containing information about bonus content
- Image
- Image model containing URLs for different sizes of an image
- Label
- Label model containing information about a record label
- Period
- Period model containing information about a time period
- Tag
- Tag model containing information about a tag