pub struct GenreTag {
pub genre_id: Option<String>,
pub name: Option<String>,
pub slug: Option<String>,
}Expand description
Genre tag model containing information about a genre tag
This struct represents a genre tag with its genre ID, name, and slug.
Examples
use qobuz_api_rust::models::GenreTag;
let genre_tag = GenreTag {
genre_id: Some("123".to_string()),
name: Some("Rock".to_string()),
slug: Some("rock".to_string()),
};Fields
genre_id: Option<String>ID of the associated genre
name: Option<String>Name of the genre tag
slug: Option<String>URL-friendly slug for the genre tag