Image

Struct Image 

pub struct Image {
    pub small: Option<String>,
    pub thumbnail: Option<String>,
    pub medium: Option<String>,
    pub large: Option<String>,
    pub extralarge: Option<String>,
    pub mega: Option<String>,
    pub back: Option<String>,
}
Image model containing URLs for different sizes of an image

This struct provides URLs for various sizes of an image, commonly used for album artwork or artist photos.

Examples

use qobuz_api_rust::models::Image;

let image = Image {
    small: Some("https://example.com/small.jpg".to_string()),
    large: Some("https://example.com/large.jpg".to_string()),
    ..Default::default()
};

Fields

small: Option<String>

URL for the small version of the image

thumbnail: Option<String>

URL for the thumbnail version of the image

medium: Option<String>

URL for the medium version of the image

large: Option<String>

URL for the large version of the image

extralarge: Option<String>

URL for the extra-large version of the image

mega: Option<String>

URL for the mega version of the image

back: Option<String>

URL for the back cover version of the image