pub struct ReleasePhysicalSupport {
pub type_field: Option<String>,
pub format: Option<String>,
pub description: Option<String>,
}Expand description
Release physical support model containing information about physical media
This struct represents information about physical media support for a release, including type, format, and description.
Examples
use qobuz_api_rust::models::ReleasePhysicalSupport;
let physical_support = ReleasePhysicalSupport {
type_field: Some("cd".to_string()),
format: Some("CD".to_string()),
description: Some("Compact Disc".to_string()),
};Fields
type_field: Option<String>Type of physical support
format: Option<String>Format of the physical support
description: Option<String>Description of the physical support