pub struct ReleaseTrackList {
pub items: Option<Vec<ReleaseTrack>>,
pub total: Option<i32>,
}Expand description
Release track list model containing a list of tracks in a release
This struct represents a list of tracks in a release along with the total count.
Examples
use qobuz_api_rust::models::{ReleaseTrackList, ReleaseTrack};
let track_list = ReleaseTrackList {
items: Some(vec![ReleaseTrack::default()]),
total: Some(10),
};Fields
items: Option<Vec<ReleaseTrack>>List of tracks in the release
total: Option<i32>Total number of tracks in the release