pub struct AlbumsSameArtist {
pub albums: Option<ItemSearchResult<Box<Album>>>,
pub artist: Option<Box<Artist>>,
}Expand description
Model containing albums by the same artist
This struct represents a collection of albums by the same artist along with information about the artist.
Examples
use qobuz_api_rust::models::{AlbumsSameArtist, ItemSearchResult, Album};
let albums_same_artist = AlbumsSameArtist {
albums: Some(ItemSearchResult::<Box<Album>>::default()),
artist: None,
};Fields
albums: Option<ItemSearchResult<Box<Album>>>Search results for albums by the same artist
artist: Option<Box<Artist>>The artist whose albums are included