Simplified user model containing basic user information
This module contains the User struct which represents a Qobuz user with their identification, personal information, account details, and subscription information.
Structs
- User
- User model representing a Qobuz user