LastUpdate

Struct LastUpdate 

pub struct LastUpdate {
Show 16 fields pub favorites: Option<String>, pub playlists: Option<String>, pub followings: Option<String>, pub subscriptions: Option<String>, pub purchases: Option<String>, pub playback_history: Option<String>, pub library: Option<String>, pub recommendations: Option<String>, pub discover: Option<String>, pub personal_radio: Option<String>, pub instant_mixes: Option<String>, pub smart_playlists: Option<String>, pub daily_mixes: Option<String>, pub weekly_mixes: Option<String>, pub monthly_mixes: Option<String>, pub yearly_mixes: Option<String>,
}
Last update model containing timestamps for various user data

This struct represents the last update times for different types of user data such as favorites, playlists, and other collections.

Examples

use qobuz_api_rust::models::LastUpdate;

let last_update = LastUpdate {
    favorites: Some("2023-01-01T00:00:00Z".to_string()),
    playlists: Some("2023-01-02T00:00:00Z".to_string()),
    ..Default::default()
};

Fields

favorites: Option<String>

Last update time for favorites

playlists: Option<String>

Last update time for playlists

followings: Option<String>

Last update time for followings

subscriptions: Option<String>

Last update time for subscriptions

purchases: Option<String>

Last update time for purchases

playback_history: Option<String>

Last update time for playback history

library: Option<String>

Last update time for the user’s library

recommendations: Option<String>

Last update time for recommendations

discover: Option<String>

Last update time for discover content

personal_radio: Option<String>

Last update time for personal radio

instant_mixes: Option<String>

Last update time for instant mixes

smart_playlists: Option<String>

Last update time for smart playlists

daily_mixes: Option<String>

Last update time for daily mixes

weekly_mixes: Option<String>

Last update time for weekly mixes

monthly_mixes: Option<String>

Last update time for monthly mixes

yearly_mixes: Option<String>

Last update time for yearly mixes